@@ -1,9 +1,10 @@
 
 
 if __name__ == '__main__':
+    import sys
     from askbob.util import setup_logging
     from rasa_sdk.endpoint import run
 
     setup_logging()
 
-    run("plugins", 5055)
+    run(sys.argv[1], sys.argv[2])
